@@ -17,7 +17,7 @@
  * This project is developed by "Ubuntu Kylin Members" team,
  * see <https://launchpad.net/~ubuntukylin~members>
  * Authors: Abel Liu <guiltyritter@gmail.com>
- *                 Shine Huang <hostc@163.com>
+ *                 Shine Huang <shenghuang@ubuntukylin.com>
  */
 
 #include "chinesecalendar.h"
@@ -27,7 +27,6 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this); m_strFileList.clear();
-//    bg = new QPixmap(":/img/chinesecalendarBGyellow.png");
     icon = QIcon(":/img/icon.png");
     icon64 = QIcon(":/img/chinesecalendar-64.png");
     mycalendat=new CCBO;
@@ -40,16 +39,6 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     connect(YearSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setYear(int)));
     connect(this->backtotoday, SIGNAL(clicked()), this, SLOT(backtoday()));
 
-//    this->TbnextMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-//    this->TbnextYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-//    this->TbpreviousMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-//    this->TbpreviousYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-//    this->backtotoday->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-//    this->YearSelect->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
-//    this->monthCombo->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
-//    this->label->setStyleSheet("QLabel{font:12pt;}");
-//    this->label_2->setStyleSheet("QLabel{font:12pt;}");
-
     QDateTime dateTime;
     QString currentTime;
     QString week;
@@ -68,10 +57,12 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
         week = "星期六";
     if(dateTime.toString("ddd") == "Sun")
         week = "星期日";
+
     currentTime = dateTime.toString("yyyy-MM-dd %1").arg(week);
     QDate day = QDate::currentDate();
     struct CCalendar datebase;
     mycalendat->ctcl_solar_to_lunar(day.year(),day.month(),day.day(),&datebase);
+
     QString chinesemonth = datebase.cmonth;
     if (chinesemonth == "一月")
         chinesemonth = "正月";
@@ -79,6 +70,7 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
         chinesemonth = "冬月";
     if (chinesemonth == "十二月")
         chinesemonth = "腊月";
+
     QString chineseday = QString("农历 %1%2").arg(chinesemonth).arg(datebase.cday);
     QString chineseyear = QString("%1年(%2年)").arg(datebase.ganzhi).arg(datebase.shengxiao);
 
@@ -102,11 +94,12 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     this->label_13->setText(chineseday);
     this->label_14->setFont(font);
     this->label_14->setText(chineseyear);
-    font.setPointSize(15);
-    this->label_15->setFont(font);
+//    font.setPointSize(15);
+//    this->label_15->setFont(font);
     font.setPointSize(10);
     this->label_17->setFont(font);
     this->label_18->setFont(font);
+
     QString yi=QString("");
     QString ji=QString("");
     if(chineseyilist.count() == 0 )
@@ -149,37 +142,24 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
         this->label_19->setText(noplan);
     else
         this->label_19->setText(haveplan);
+
     pa.setColor(QPalette::WindowText,Qt::white);
     this->label->setPalette(pa);
     this->label_2->setPalette(pa);
-    this->label_15->setPalette(pa);
-    this->label_4->setPalette(pa);
-    this->label_5->setPalette(pa);
-    this->label_6->setPalette(pa);
-    this->label_7->setPalette(pa);
-    this->label_8->setPalette(pa);
-
-    pa.setColor(QPalette::WindowText,QColor(255,255,255));
-    this->label_3->setPalette(pa);
-    this->label_9->setPalette(pa); 
 
     pa.setColor(QPalette::WindowText,Qt::black);
     this->label_18->setPalette(pa);
 
-    pa.setColor(QPalette::WindowText,QColor(235,74,20));
-    this->label_10->setPalette(pa);
-    this->label_12->setPalette(pa);
-    this->label_13->setPalette(pa);
-    this->label_14->setPalette(pa);
-
-    pa.setColor(QPalette::WindowText,Qt::white);
-    this->label_19->setPalette(pa);
-
-    pa.setColor(QPalette::WindowText,Qt::red);
-    this->label_11->setPalette(pa);
-    this->label_17->setPalette(pa);
+    // some set
+    this->TbnextMonth->setFocusPolicy(Qt::NoFocus);
+    this->TbnextYear->setFocusPolicy(Qt::NoFocus);
+    this->TbpreviousMonth->setFocusPolicy(Qt::NoFocus);
+    this->TbpreviousYear->setFocusPolicy(Qt::NoFocus);
+    this->backtotoday->setFocusPolicy(Qt::NoFocus);
 
+    // init date item
     map = new QMap<QString, DateItem *>();
+
     DateItem *dateitem00 = new DateItem(this);
     dateitem00->show();
     map->insert(QString("1-1"), dateitem00 );
@@ -467,12 +447,13 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     connect(timer,SIGNAL(timeout()),this,SLOT(setTime()));
     timer->start();
 
-    QBitmap objBitmap(size());
-    QPainter painter(&objBitmap);
-    painter.fillRect(rect(),Qt::white);
-    painter.setBrush(QColor(0,0,0));
-    painter.drawRoundedRect(this->rect(),10,10);
-    setMask(objBitmap);
+    // mainwindow radius rect
+//    QBitmap objBitmap(size());
+//    QPainter painter(&objBitmap);
+//    painter.fillRect(rect(),Qt::white);
+//    painter.setBrush(QColor(0,0,0));
+//    painter.drawRoundedRect(this->rect(),10,10);
+//    setMask(objBitmap);
 
     aboutDlg = new AboutDialog();
     aboutDlg->hide();
@@ -482,7 +463,7 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     note = new Cnote;
     QDesktopWidget desktop;
     int width = desktop.screenGeometry().width();
-    note->setGeometry(QRect(width-400,80,224,252));
+    note->setGeometry(QRect(width-400,80,196,206));
     connect(note,SIGNAL(save(QString)),this,SLOT(savedata(QString)));
     note->hide();
 }
@@ -543,11 +524,11 @@ void ChineseCalendar::createTray()
     connect(actionStaysNormal, SIGNAL(triggered()), this, SLOT(slotChangeMode()));
 
     // default skin
-    this->actionDefault = new QAction(tr("Default"), this);
-    actionDefault->setCheckable(true);
-    actionDefault->setChecked(true);
-    m_skinName = QString("default");
-    connect(actionDefault, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
+//    this->actionDefault = new QAction(tr("Default"), this);
+//    actionDefault->setCheckable(true);
+//    actionDefault->setChecked(true);
+//    m_skinName = QString("default");
+//    connect(actionDefault, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
 
     // blue skin
     this->actionSkin = new QAction(tr("Blue"), this);
@@ -555,15 +536,15 @@ void ChineseCalendar::createTray()
     connect(actionSkin, SIGNAL(triggered()), this, SLOT(slotChangeSkin()));
 
     this->skinMenu = new QMenu(tr("换肤"), this);
-    this->skinMenu->addAction(actionDefault);
+//    this->skinMenu->addAction(actionDefault);
     this->skinMenu->addAction(actionSkin);
 
     QActionGroup *actSkinGrp = new QActionGroup(this);
-    actSkinGrp->addAction(actionDefault);
+//    actSkinGrp->addAction(actionDefault);
     actSkinGrp->addAction(actionSkin);
 
     readSetting();
-    actionDefault->setChecked(m_skinName == "default");
+//    actionDefault->setChecked(m_skinName == "default");
     actionSkin->setChecked(m_skinName == "blue");
 
     // read user customizated skin files
@@ -618,222 +599,232 @@ void ChineseCalendar::createTray()
 
 void ChineseCalendar::paintEvent(QPaintEvent *)
 {
-    QStyleOption opt;
-    opt.init(this);
-    QPainter painter(this);
+//    QStyleOption opt;
+//    opt.init(this);
+//    QPainter painter(this);
 //    painter.drawPixmap(0,0,width(),height(),*bg);
-    style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
+//    style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 
-//    painter.setPen(Qt::gray);
-    painter.setPen(QColor(255,121,3,100));
+////    painter.setPen(Qt::gray);
+//    painter.setPen(QColor(255,121,3,100));
 
-    if(!isTall)
-    {
-    //row
-        painter.drawLine(5,108,390,108);
-        painter.drawLine(5,147,390,147);
-        painter.drawLine(5,186,390,186);
-        painter.drawLine(5,225,390,225);
-        painter.drawLine(5,264,390,264);
-//        painter.drawLine(5,303,390,303);
-    }
-    else
-    {
-        painter.drawLine(5,116,390,116);
-        painter.drawLine(5,163,390,163);
-        painter.drawLine(5,210,390,210);
-        painter.drawLine(5,257,390,257);
-//        painter.drawLine(5,304,390,304);
-    }
-    //column
-    painter.drawLine(60,69,60,303);
-    painter.drawLine(115,69,115,303);
-    painter.drawLine(170,69,170,303);
-    painter.drawLine(225,69,225,303);
-    painter.drawLine(280,69,280,303);
-    painter.drawLine(335,69,335,303);
+//    if(!isTall)
+//    {
+//    //row
+//        painter.drawLine(5,108,410,108);
+//        painter.drawLine(5,147,410,147);
+//        painter.drawLine(5,186,410,186);
+//        painter.drawLine(5,225,410,225);
+//        painter.drawLine(5,264,410,264);
+////        painter.drawLine(5,303,410,303);
+//    }
+//    else
+//    {
+//        painter.drawLine(5,116,410,116);
+//        painter.drawLine(5,163,410,163);
+//        painter.drawLine(5,210,410,210);
+//        painter.drawLine(5,257,410,257);
+////        painter.drawLine(5,304,410,304);
+//    }
+//    //column
+//    painter.drawLine(60,69,60,303);
+//    painter.drawLine(115,69,115,303);
+//    painter.drawLine(170,69,170,303);
+//    painter.drawLine(225,69,225,303);
+//    painter.drawLine(280,69,280,303);
+//    painter.drawLine(335,69,335,303);
 }
 
 void ChineseCalendar::setItemLayout()
 {
     if(isTall == false)
     {
-        map->value("1-1")->resizeItem(55,47);
-        map->value("1-2")->resizeItem(55,47);
-        map->value("1-3")->resizeItem(55,47);
-        map->value("1-4")->resizeItem(55,47);
-        map->value("1-5")->resizeItem(55,47);
-        map->value("1-6")->resizeItem(55,47);
-        map->value("1-7")->resizeItem(55,47);
-        map->value("2-1")->resizeItem(55,47);
-        map->value("2-2")->resizeItem(55,47);
-        map->value("2-3")->resizeItem(55,47);
-        map->value("2-4")->resizeItem(55,47);
-        map->value("2-5")->resizeItem(55,47);
-        map->value("2-6")->resizeItem(55,47);
-        map->value("2-7")->resizeItem(55,47);
-        map->value("3-1")->resizeItem(55,47);
-        map->value("3-2")->resizeItem(55,47);
-        map->value("3-3")->resizeItem(55,47);
-        map->value("3-4")->resizeItem(55,47);
-        map->value("3-5")->resizeItem(55,47);
-        map->value("3-6")->resizeItem(55,47);
-        map->value("3-7")->resizeItem(55,47);
-        map->value("4-1")->resizeItem(55,47);
-        map->value("4-2")->resizeItem(55,47);
-        map->value("4-3")->resizeItem(55,47);
-        map->value("4-4")->resizeItem(55,47);
-        map->value("4-5")->resizeItem(55,47);
-        map->value("4-6")->resizeItem(55,47);
-        map->value("4-7")->resizeItem(55,47);
-        map->value("5-1")->resizeItem(55,47);
-        map->value("5-2")->resizeItem(55,47);
-        map->value("5-3")->resizeItem(55,47);
-        map->value("5-4")->resizeItem(55,47);
-        map->value("5-5")->resizeItem(55,47);
-        map->value("5-6")->resizeItem(55,47);
-        map->value("5-7")->resizeItem(55,47);
-        map->value("6-1")->resizeItem(55,47);
-        map->value("6-2")->resizeItem(55,47);
-        map->value("6-3")->resizeItem(55,47);
-        map->value("6-4")->resizeItem(55,47);
-        map->value("6-5")->resizeItem(55,47);
-        map->value("6-6")->resizeItem(55,47);
-        map->value("6-7")->resizeItem(55,47);
+        map->value("1-1")->resizeItem(49,50);
+        map->value("1-2")->resizeItem(49,50);
+        map->value("1-3")->resizeItem(49,50);
+        map->value("1-4")->resizeItem(49,50);
+        map->value("1-5")->resizeItem(49,50);
+        map->value("1-6")->resizeItem(49,50);
+        map->value("1-7")->resizeItem(49,50);
+        map->value("2-1")->resizeItem(49,50);
+        map->value("2-2")->resizeItem(49,50);
+        map->value("2-3")->resizeItem(49,50);
+        map->value("2-4")->resizeItem(49,50);
+        map->value("2-5")->resizeItem(49,50);
+        map->value("2-6")->resizeItem(49,50);
+        map->value("2-7")->resizeItem(49,50);
+        map->value("3-1")->resizeItem(49,50);
+        map->value("3-2")->resizeItem(49,50);
+        map->value("3-3")->resizeItem(49,50);
+        map->value("3-4")->resizeItem(49,50);
+        map->value("3-5")->resizeItem(49,50);
+        map->value("3-6")->resizeItem(49,50);
+        map->value("3-7")->resizeItem(49,50);
+        map->value("4-1")->resizeItem(49,50);
+        map->value("4-2")->resizeItem(49,50);
+        map->value("4-3")->resizeItem(49,50);
+        map->value("4-4")->resizeItem(49,50);
+        map->value("4-5")->resizeItem(49,50);
+        map->value("4-6")->resizeItem(49,50);
+        map->value("4-7")->resizeItem(49,50);
+        map->value("5-1")->resizeItem(49,50);
+        map->value("5-2")->resizeItem(49,50);
+        map->value("5-3")->resizeItem(49,50);
+        map->value("5-4")->resizeItem(49,50);
+        map->value("5-5")->resizeItem(49,50);
+        map->value("5-6")->resizeItem(49,50);
+        map->value("5-7")->resizeItem(49,50);
+        map->value("6-1")->resizeItem(49,50);
+        map->value("6-2")->resizeItem(49,50);
+        map->value("6-3")->resizeItem(49,50);
+        map->value("6-4")->resizeItem(49,50);
+        map->value("6-5")->resizeItem(49,50);
+        map->value("6-6")->resizeItem(49,50);
+        map->value("6-7")->resizeItem(49,50);
         isTall = true;
     }
-    map->value("1-1")->move(5,69);
-    map->value("1-2")->move(60,69);
-    map->value("1-3")->move(115,69);
-    map->value("1-4")->move(170,69);
-    map->value("1-5")->move(225,69);
-    map->value("1-6")->move(280,69);
-    map->value("1-7")->move(335,69);
-    map->value("2-1")->move(5,116);
-    map->value("2-2")->move(60,116);
-    map->value("2-3")->move(115,116);
-    map->value("2-4")->move(170,116);
-    map->value("2-5")->move(225,116);
-    map->value("2-6")->move(280,116);
-    map->value("2-7")->move(335,116);
-    map->value("3-1")->move(5,163);
-    map->value("3-2")->move(60,163);
-    map->value("3-3")->move(115,163);
-    map->value("3-4")->move(170,163);
-    map->value("3-5")->move(225,163);
-    map->value("3-6")->move(280,163);
-    map->value("3-7")->move(335,163);
-    map->value("4-1")->move(5,210);
-    map->value("4-2")->move(60,210);
-    map->value("4-3")->move(115,210);
-    map->value("4-4")->move(170,210);
-    map->value("4-5")->move(225,210);
-    map->value("4-6")->move(280,210);
-    map->value("4-7")->move(335,210);
-    map->value("5-1")->move(5,257);
-    map->value("5-2")->move(60,257);
-    map->value("5-3")->move(115,257);
-    map->value("5-4")->move(170,257);
-    map->value("5-5")->move(225,257);
-    map->value("5-6")->move(280,257);
-    map->value("5-7")->move(335,257);
-    map->value("6-1")->move(5,304);
-    map->value("6-2")->move(60,304);
-    map->value("6-3")->move(115,304);
-    map->value("6-4")->move(170,304);
-    map->value("6-5")->move(225,304);
-    map->value("6-6")->move(280,304);
-    map->value("6-7")->move(335,304);
+    map->value("1-1")->move(0,71);
+    map->value("1-2")->move(50,71);
+    map->value("1-3")->move(100,71);
+    map->value("1-4")->move(150,71);
+    map->value("1-5")->move(200,71);
+    map->value("1-6")->move(250,71);
+    map->value("1-7")->move(300,71);
+
+    map->value("2-1")->move(0,122);
+    map->value("2-2")->move(50,122);
+    map->value("2-3")->move(100,122);
+    map->value("2-4")->move(150,122);
+    map->value("2-5")->move(200,122);
+    map->value("2-6")->move(250,122);
+    map->value("2-7")->move(300,122);
+
+    map->value("3-1")->move(0,173);
+    map->value("3-2")->move(50,173);
+    map->value("3-3")->move(100,173);
+    map->value("3-4")->move(150,173);
+    map->value("3-5")->move(200,173);
+    map->value("3-6")->move(250,173);
+    map->value("3-7")->move(300,173);
+
+    map->value("4-1")->move(0,224);
+    map->value("4-2")->move(50,224);
+    map->value("4-3")->move(100,224);
+    map->value("4-4")->move(150,224);
+    map->value("4-5")->move(200,224);
+    map->value("4-6")->move(250,224);
+    map->value("4-7")->move(300,224);
+
+    map->value("5-1")->move(0,275);
+    map->value("5-2")->move(50,275);
+    map->value("5-3")->move(100,275);
+    map->value("5-4")->move(150,275);
+    map->value("5-5")->move(200,275);
+    map->value("5-6")->move(250,275);
+    map->value("5-7")->move(300,275);
+
+    map->value("6-1")->move(0,326);
+    map->value("6-2")->move(50,326);
+    map->value("6-3")->move(100,326);
+    map->value("6-4")->move(150,326);
+    map->value("6-5")->move(200,326);
+    map->value("6-6")->move(250,326);
+    map->value("6-7")->move(300,326);
 }
 
 void ChineseCalendar::resetItemLayout()
 {
-    map->value("1-1")->resizeItem(55,39);
-    map->value("1-2")->resizeItem(55,39);
-    map->value("1-3")->resizeItem(55,39);
-    map->value("1-4")->resizeItem(55,39);
-    map->value("1-5")->resizeItem(55,39);
-    map->value("1-6")->resizeItem(55,39);
-    map->value("1-7")->resizeItem(55,39);
-    map->value("2-1")->resizeItem(55,39);
-    map->value("2-2")->resizeItem(55,39);
-    map->value("2-3")->resizeItem(55,39);
-    map->value("2-4")->resizeItem(55,39);
-    map->value("2-5")->resizeItem(55,39);
-    map->value("2-6")->resizeItem(55,39);
-    map->value("2-7")->resizeItem(55,39);
-    map->value("3-1")->resizeItem(55,39);
-    map->value("3-2")->resizeItem(55,39);
-    map->value("3-3")->resizeItem(55,39);
-    map->value("3-4")->resizeItem(55,39);
-    map->value("3-5")->resizeItem(55,39);
-    map->value("3-6")->resizeItem(55,39);
-    map->value("3-7")->resizeItem(55,39);
-    map->value("4-1")->resizeItem(55,39);
-    map->value("4-2")->resizeItem(55,39);
-    map->value("4-3")->resizeItem(55,39);
-    map->value("4-4")->resizeItem(55,39);
-    map->value("4-5")->resizeItem(55,39);
-    map->value("4-6")->resizeItem(55,39);
-    map->value("4-7")->resizeItem(55,39);
-    map->value("5-1")->resizeItem(55,39);
-    map->value("5-2")->resizeItem(55,39);
-    map->value("5-3")->resizeItem(55,39);
-    map->value("5-4")->resizeItem(55,39);
-    map->value("5-5")->resizeItem(55,39);
-    map->value("5-6")->resizeItem(55,39);
-    map->value("5-7")->resizeItem(55,39);
-    map->value("6-1")->resizeItem(55,39);
-    map->value("6-2")->resizeItem(55,39);
-    map->value("6-3")->resizeItem(55,39);
-    map->value("6-4")->resizeItem(55,39);
-    map->value("6-5")->resizeItem(55,39);
-    map->value("6-6")->resizeItem(55,39);
-    map->value("6-7")->resizeItem(55,39);
+    map->value("1-1")->resizeItem(49,41);
+    map->value("1-2")->resizeItem(49,41);
+    map->value("1-3")->resizeItem(49,41);
+    map->value("1-4")->resizeItem(49,41);
+    map->value("1-5")->resizeItem(49,41);
+    map->value("1-6")->resizeItem(49,41);
+    map->value("1-7")->resizeItem(49,41);
+    map->value("2-1")->resizeItem(49,41);
+    map->value("2-2")->resizeItem(49,41);
+    map->value("2-3")->resizeItem(49,41);
+    map->value("2-4")->resizeItem(49,41);
+    map->value("2-5")->resizeItem(49,41);
+    map->value("2-6")->resizeItem(49,41);
+    map->value("2-7")->resizeItem(49,41);
+    map->value("3-1")->resizeItem(49,41);
+    map->value("3-2")->resizeItem(49,41);
+    map->value("3-3")->resizeItem(49,41);
+    map->value("3-4")->resizeItem(49,41);
+    map->value("3-5")->resizeItem(49,41);
+    map->value("3-6")->resizeItem(49,41);
+    map->value("3-7")->resizeItem(49,41);
+    map->value("4-1")->resizeItem(49,41);
+    map->value("4-2")->resizeItem(49,41);
+    map->value("4-3")->resizeItem(49,41);
+    map->value("4-4")->resizeItem(49,41);
+    map->value("4-5")->resizeItem(49,41);
+    map->value("4-6")->resizeItem(49,41);
+    map->value("4-7")->resizeItem(49,41);
+    map->value("5-1")->resizeItem(49,41);
+    map->value("5-2")->resizeItem(49,41);
+    map->value("5-3")->resizeItem(49,41);
+    map->value("5-4")->resizeItem(49,41);
+    map->value("5-5")->resizeItem(49,41);
+    map->value("5-6")->resizeItem(49,41);
+    map->value("5-7")->resizeItem(49,41);
+    map->value("6-1")->resizeItem(49,41);
+    map->value("6-2")->resizeItem(49,41);
+    map->value("6-3")->resizeItem(49,41);
+    map->value("6-4")->resizeItem(49,41);
+    map->value("6-5")->resizeItem(49,41);
+    map->value("6-6")->resizeItem(49,41);
+    map->value("6-7")->resizeItem(49,41);
     isTall = false;
 
-    map->value("1-1")->move(5,69);
-    map->value("1-2")->move(60,69);
-    map->value("1-3")->move(115,69);
-    map->value("1-4")->move(170,69);
-    map->value("1-5")->move(225,69);
-    map->value("1-6")->move(280,69);
-    map->value("1-7")->move(335,69);
-    map->value("2-1")->move(5,108);
-    map->value("2-2")->move(60,108);
-    map->value("2-3")->move(115,108);
-    map->value("2-4")->move(170,108);
-    map->value("2-5")->move(225,108);
-    map->value("2-6")->move(280,108);
-    map->value("2-7")->move(335,108);
-    map->value("3-1")->move(5,147);
-    map->value("3-2")->move(60,147);
-    map->value("3-3")->move(115,147);
-    map->value("3-4")->move(170,147);
-    map->value("3-5")->move(225,147);
-    map->value("3-6")->move(280,147);
-    map->value("3-7")->move(335,147);
-    map->value("4-1")->move(5,186);
-    map->value("4-2")->move(60,186);
-    map->value("4-3")->move(115,186);
-    map->value("4-4")->move(170,186);
-    map->value("4-5")->move(225,186);
-    map->value("4-6")->move(280,186);
-    map->value("4-7")->move(335,186);
-    map->value("5-1")->move(5,225);
-    map->value("5-2")->move(60,225);
-    map->value("5-3")->move(115,225);
-    map->value("5-4")->move(170,225);
-    map->value("5-5")->move(225,225);
-    map->value("5-6")->move(280,225);
-    map->value("5-7")->move(335,225);
-    map->value("6-1")->move(5,264);
-    map->value("6-2")->move(60,264);
-    map->value("6-3")->move(115,264);
-    map->value("6-4")->move(170,264);
-    map->value("6-5")->move(225,264);
-    map->value("6-6")->move(280,264);
-    map->value("6-7")->move(335,264);
+    map->value("1-1")->move(0,71);
+    map->value("1-2")->move(50,71);
+    map->value("1-3")->move(100,71);
+    map->value("1-4")->move(150,71);
+    map->value("1-5")->move(200,71);
+    map->value("1-6")->move(250,71);
+    map->value("1-7")->move(300,71);
+
+    map->value("2-1")->move(0,113);
+    map->value("2-2")->move(50,113);
+    map->value("2-3")->move(100,113);
+    map->value("2-4")->move(150,113);
+    map->value("2-5")->move(200,113);
+    map->value("2-6")->move(250,113);
+    map->value("2-7")->move(300,113);
+
+    map->value("3-1")->move(0,155);
+    map->value("3-2")->move(50,155);
+    map->value("3-3")->move(100,155);
+    map->value("3-4")->move(150,155);
+    map->value("3-5")->move(200,155);
+    map->value("3-6")->move(250,155);
+    map->value("3-7")->move(300,155);
+
+    map->value("4-1")->move(0,197);
+    map->value("4-2")->move(50,197);
+    map->value("4-3")->move(100,197);
+    map->value("4-4")->move(150,197);
+    map->value("4-5")->move(200,197);
+    map->value("4-6")->move(250,197);
+    map->value("4-7")->move(300,197);
+
+    map->value("5-1")->move(0,239);
+    map->value("5-2")->move(50,239);
+    map->value("5-3")->move(100,239);
+    map->value("5-4")->move(150,239);
+    map->value("5-5")->move(200,239);
+    map->value("5-6")->move(250,239);
+    map->value("5-7")->move(300,239);
+
+    map->value("6-1")->move(0,281);
+    map->value("6-2")->move(50,281);
+    map->value("6-3")->move(100,281);
+    map->value("6-4")->move(150,281);
+    map->value("6-5")->move(200,281);
+    map->value("6-6")->move(250,281);
+    map->value("6-7")->move(300,281);
 }
 
 void ChineseCalendar::setTime()
@@ -955,7 +946,6 @@ void ChineseCalendar::backtoday()
     monthCombo->setCurrentIndex(today.month() - 1);
     selectedDate = today;
     setCalendar();
-
 }
 
 void ChineseCalendar::setCalendar(bool flag)
@@ -1447,7 +1437,8 @@ void ChineseCalendar::readSetting()
     m_nMode = settings.value("mode", 3).toInt();
 
     // 读取皮肤名
-    m_skinName = settings.value("skin", "default").toString();
+//    m_skinName = settings.value("skin", "default").toString();
+    m_skinName = settings.value("skin", "blue").toString();
 
     settings.endGroup();
 
